summaryrefslogtreecommitdiffstats
path: root/src/kvilib/ext/kvi_regusersdb.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kvilib/ext/kvi_regusersdb.cpp')
-rw-r--r--src/kvilib/ext/kvi_regusersdb.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/src/kvilib/ext/kvi_regusersdb.cpp b/src/kvilib/ext/kvi_regusersdb.cpp
index c60d2c9e..0a0c632a 100644
--- a/src/kvilib/ext/kvi_regusersdb.cpp
+++ b/src/kvilib/ext/kvi_regusersdb.cpp
@@ -47,7 +47,7 @@
@body:
[big]Introduction[/big][br]
The "registered user database" is basically a set of users with associated
- [doc:irc_tqmasks]irc-tqmasks[/doc] and properties.[br]
+ [doc:irc_masks]irc-masks[/doc] and properties.[br]
It is used to recognize users on IRC and associate properties to them.[br]
This works more or less like the IRC ban list, K-Line list, or invite list.[br]
[big]User entry[/big][br]
@@ -55,20 +55,20 @@
It may be the nickname of the user that you want to match, or the real name (if you know it)
or any other string (even with spaces). The name is an "internal identifier" for the user entry:
each name maps to a single entry and each entry has a single name.[br]
- Each entry has a set of registration [doc:irc_tqmasks]irc-tqmasks[/doc]: these tqmasks
+ Each entry has a set of registration [doc:irc_masks]irc-masks[/doc]: these masks
are used to recognize the user on irc.[br]
[br]
- [big]Registration tqmasks[/big][br]
- The tqmasks have the common IRC tqmask format: [b]<nick>!<user>@<host>[/b][br]
- The tqmasks may contain '*' and '?' wildcards that match any portion of text.[br]
+ [big]Registration masks[/big][br]
+ The masks have the common IRC tqmask format: [b]<nick>!<user>@<host>[/b][br]
+ The masks may contain '*' and '?' wildcards that match any portion of text.[br]
[b]*!*@*[/b][br]
[b]Pragma!*@*[/b][br]
[b]*!~daemon@*[/b][br]
[b]Pragma!*daemon@*.it[/b][br]
[b]Pragma!?daemon@some*.it[/b][br]
[b]Pragma!~daemon@some.host.it[/b][br]
- Are examples of valid registration tqmasks.[br]
- The tqmasks with wildcards can actually match more than a single user.[br]
+ Are examples of valid registration masks.[br]
+ The masks with wildcards can actually match more than a single user.[br]
For example the tqmask *!root@*.host.com will match all the users
having root as username and coming from the host.com domain.[br]
For this reason putting wildcards in nicknames could become a problem
@@ -88,7 +88,7 @@
<variable-number>.somewhere.in.time.org.[br]
You will add an entry with name "Derek Riggs" and a registration tqmask like the following:
Eddie!stranger@*.somewhere.in.time.org.[br]
- If the IRC servers keep adding strange characters ([doc:irc_tqmasks]prefixes[/doc]) at the beginning of his username you may use
+ If the IRC servers keep adding strange characters ([doc:irc_masks]prefixes[/doc]) at the beginning of his username you may use
Eddie!*stranger@*.somewhere.in.time.org.[br]
If Eddie also often connects from the wasted.years.org domain and gets 'eddie' as username there, you might add a second registration tqmask as follows:
Eddie!*eddie@*.wasted.years.org.[br]
@@ -98,7 +98,7 @@
and you're implementing an auto-kick system, the correct tqmask to register is "Eddie!*@*.org".[br]
[br]
KVirc ties to be smart , and always find the most correct match for an user:
- If you have two tqmasks registered: Pragma!*xor@*.myisp.it and *!*@*.myisp.it,
+ If you have two masks registered: Pragma!*xor@*.myisp.it and *!*@*.myisp.it,
kvirc will match Pragma!~xor@233-dyn.myisp.it with the first one even if the second
one matches too; the firs one is a best match.[br]
[br]
@@ -117,7 +117,7 @@
[br]
[big]The interface to the database[/big][br]
The [module:reguser]reguser module[/module] is the interface to the "registered users database".[br]
- It provides a set of commands for adding and removing tqmasks and manipulating properties.[br]
+ It provides a set of commands for adding and removing masks and manipulating properties.[br]
*/
//============================================================================================================
@@ -359,7 +359,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::getUser(const TQString & name)
return u;
}
-static void append_tqmask_to_list(KviRegisteredMaskList *l,KviRegisteredUser *u,KviIrcMask *tqmask)
+static void append_mask_to_list(KviRegisteredMaskList *l,KviRegisteredUser *u,KviIrcMask *tqmask)
{
KviRegisteredMask * newMask = new KviRegisteredMask(u,tqmask);
int idx = 0;
@@ -393,7 +393,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addMask(KviRegisteredUser * u,Kvi
}
}
// not found ...ok... add it
// tqmasks with more info go first in the list
l = m_pWildMaskList;
} else {
l = m_pMaskDict->tqfind(tqmask->nick());
@@ -421,7 +421,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addMask(KviRegisteredUser * u,Kvi
delete l;
l = 0;
} else {
- append_tqmask_to_list(l,u,tqmask);
+ append_mask_to_list(l,u,tqmask);
m_pMaskDict->insert(tqmask->nick(),l);
}
return 0;
@@ -433,7 +433,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addMask(KviRegisteredUser * u,Kvi
debug("ops...got an incoherent regusers action...recovered ?");
return 0; // ops...already there ?
}
- append_tqmask_to_list(l,u,tqmask);
+ append_mask_to_list(l,u,tqmask);
return 0;
}
@@ -450,8 +450,8 @@ void KviRegisteredUserDataBase::copyFrom(KviRegisteredUserDataBase * db)
while(KviRegisteredUser * theCur = it.current())
{
KviRegisteredUser * u = getUser(theCur->name());
- // copy tqmasks
- KviPointerList<KviIrcMask> * l = theCur->tqmaskList();
+ // copy masks
+ KviPointerList<KviIrcMask> * l = theCur->maskList();
for(KviIrcMask * m=l->first();m;m = l->next())
{
KviIrcMask * m2 = new KviIrcMask(*m);
@@ -488,7 +488,7 @@ bool KviRegisteredUserDataBase::removeUser(const TQString & name)
if(name.isEmpty()) return false;
KviRegisteredUser * u = m_pUserDict->tqfind(name);
if(!u)return false;
- while(KviIrcMask * tqmask = u->tqmaskList()->first())
+ while(KviIrcMask * tqmask = u->maskList()->first())
{
if(!removeMaskByPointer(tqmask))
debug("Ops... removeMaskByPointer(%s) failed ?",KviTQString::toUtf8(name).data());
@@ -565,7 +565,7 @@ bool KviRegisteredUserDataBase::removeMaskByPointer(KviIrcMask * tqmask)
/*
KviRegisteredUser * KviRegisteredUserDataBase::findMatchingUser(const KviIrcMask &tqmask)
{
- // first lookup the nickname in the tqmaskDict
+ // first lookup the nickname in the maskDict
KviRegisteredMaskList * l = m_pMaskDict->tqfind(tqmask.nick());
if(l)
{
@@ -591,7 +591,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::findMatchingUser(const TQString &
KviRegisteredMask * KviRegisteredUserDataBase::findMatchingMask(const TQString & nick,const TQString &user,const TQString & host)
{
- // first lookup the nickname in the tqmaskDict
+ // first lookup the nickname in the maskDict
if(nick.isEmpty()) return false;
KviRegisteredMaskList * l = m_pMaskDict->tqfind(nick);
if(l)
@@ -618,7 +618,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::findUserWithMask(const KviIrcMask
KviRegisteredMask * KviRegisteredUserDataBase::findExactMask(const KviIrcMask &tqmask)
{
- // first lookup the nickname in the tqmaskDict
+ // first lookup the nickname in the maskDict
if(tqmask.nick()=="") return 0;
KviRegisteredMaskList * l = m_pMaskDict->tqfind(tqmask.nick());
if(l)
@@ -672,7 +672,7 @@ void KviRegisteredUserDataBase::load(const TQString & filename)
{
tmp.remove(0,5);
u->setProperty(tmp,*(sdi.current()));
- } else if(KviTQString::equalCSN("tqmask_",tmp,5))
+ } else if(KviTQString::equalCSN("mask_",tmp,5))
{
KviIrcMask * tqmask = new KviIrcMask(*(sdi.current()));
addMask(u,tqmask);
@@ -716,12 +716,12 @@ void KviRegisteredUserDataBase::save(const TQString & filename)
++pit;
}
}
- // Write tqmasks
+ // Write masks
int idx = 0;
- for(KviIrcMask * m = it.current()->tqmaskList()->first();m;m = it.current()->tqmaskList()->next())
+ for(KviIrcMask * m = it.current()->maskList()->first();m;m = it.current()->maskList()->next())
{
TQString tmp;
- KviTQString::sprintf(tmp,"tqmask_%d",idx);
+ KviTQString::sprintf(tmp,"mask_%d",idx);
TQString tqmask;
m->tqmask(tqmask,KviIrcMask::NickUserHost);
cfg.writeEntry(tmp,tqmask);
@@ -393,7 +393,7 @@ KviRegisteredUser * KviRegisteredUserDataBase::addMask(KviRegisteredUser * u,Kvi
}
// not found ...ok... add it
- // tqmasks with more info go first in the list
+ // masks with more info go first in the list
l = m_pWildMaskList;
} else {